;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ruby-electric" "20250110.1017"
  "Minor mode for electrically editing ruby code."
  ()
  :url "https://github.com/ruby/elisp-ruby-electric"
  :commit "c53376da891713e0c49f01aad2ff64d4fbb0b812"
  :revdesc "c53376da8917"
  :keywords '("languages" "ruby")
  :maintainers '(("Akinori MUSHA" . "knu@iDaemons.org")))
